@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-# This file is a part of DDT (https://github.com/txels/ddt)
+# This file is a part of DDT (https://github.com/datadriventests/ddt)
 # Copyright 2012-2015 Carles Barrobés and DDT contributors
 # For the exact contribution history, see the git revision log.
 # DDT is licensed under the MIT License, included in
-# https://github.com/txels/ddt/blob/master/LICENSE.md
+# https://github.com/datadriventests/ddt/blob/master/LICENSE.md
 
 import inspect
 import json
@@ -19,16 +19,17 @@ except ImportError:  # pragma: no cover
 else:
     _have_yaml = True
 
-__version__ = '1.2.1'
+__version__ = '1.3.1'
 
 # These attributes will not conflict with any real python attribute
 # They are added to the decorated test method and processed later
 # by the `ddt` class decorator.
 
-DATA_ATTR = '%values'      # store the data the test must run with
-FILE_ATTR = '%file_path'   # store the path to JSON file
-UNPACK_ATTR = '%unpack'    # remember that we have to unpack values
-index_len = 5              # default max length of case index
+DATA_ATTR = '%values'              # store the data the test must run with
+FILE_ATTR = '%file_path'           # store the path to JSON file
+YAML_LOADER_ATTR = '%yaml_loader'  # store custom yaml loader for serialization
+UNPACK_ATTR = '%unpack'            # remember that we have to unpack values
+index_len = 5                      # default max length of case index
 
 
 try:
@@ -79,7 +80,7 @@ def idata(iterable):
     return wrapper
 
 
-def file_data(value):
+def file_data(value, yaml_loader=None):
     """
     Method decorator to add to your test methods.
 
@@ -97,9 +98,14 @@ def file_data(value):
     In case of a dict, keys will be used as suffixes to the name of the
     test case, and values will be fed as test data.
 
+    ``yaml_loader`` can be used to customize yaml deserialization.
+    The default is ``None``, which results in using the ``yaml.safe_load``
+    method.
     """
     def wrapper(func):
         setattr(func, FILE_ATTR, value)
+        if yaml_loader:
+            setattr(func, YAML_LOADER_ATTR, yaml_loader)
         return func
     return wrapper
 
@@ -212,7 +218,11 @@ def process_file_data(cls, name, func, file_attr):
     with codecs.open(data_file_path, 'r', 'utf-8') as f:
         # Load the data from YAML or JSON
         if _is_yaml_file:
-            data = yaml.safe_load(f)
+            if hasattr(func, YAML_LOADER_ATTR):
+                yaml_loader = getattr(func, YAML_LOADER_ATTR)
+                data = yaml.load(f, Loader=yaml_loader)
+            else:
+                data = yaml.safe_load(f)
         else:
             data = json.load(f)
 
